$VAR1 = {
          'guest' => {},
          'admin' => {}
        };
$session =$VAR1;